@@ -28,7 +28,7 @@ apt-get install libqbit-application-model-db-perl (http://perlhub.ru/)
 =cut
 
 package QBit::Application::Model::DB;
-$QBit::Application::Model::DB::VERSION = '0.026';
+$QBit::Application::Model::DB::VERSION = '0.027';
 use qbit;
 
 use base qw(QBit::Application::Model);
@@ -234,7 +234,7 @@ sub init {
               if $self->can($table_name);
             {
                 no strict 'refs';
-                *{"$class::$table_name"} = sub {
+                *{$class . '::' . $table_name} = sub {
                     my ($self) = @_;
 
                     $self->{'__TABLES__'}{$table_name} = $tables{$table_name}->{'class'}->new(
